@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2007,2008,2009,2010,2011,2012
+ * Copyright (C) 2007,2008,2009,2010,2011,2012,2013
  *               Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 /***************************************************************************
@@ -29,6 +29,7 @@
 #include <QSet>
 #include <solid/networking.h>
 
+class KJob;
 class QEvent;
 
 class KSelectAction;
@@ -97,7 +98,6 @@ signals:
     void certificate(QString);
     void closeAsked();
     void fontChanged(QFont);
-    void encryptFiles(KUrl::List);
 
 public slots:
     void slotGenerateKey();
@@ -190,8 +190,25 @@ private slots:
     void slotMenu(const QPoint &);
 
     void slotPreImportKey();
+    void slotSendEmail();
     void slotedit();
+
+    /**
+     * @brief start an "add to addressbook" operation
+     *
+     * This searches if given id already exists in the addressbook.
+     * The search result is handled in slotAddressbookSearchResult()
+     */
     void addToKAB();
+
+    /**
+     * @brief add or change the addressbook entry
+     * @param job the search job
+     *
+     * This handles the result of the search started in addToKAB().
+     */
+    void slotAddressbookSearchResult(KJob *job);
+
     void editGroup();
     void createNewGroup();
     void deleteGroup();
@@ -206,6 +223,7 @@ private slots:
     void importRemoteFinished(int result);
     void slotDelKeyDone(int ret);
     void slotSetClip(int result);
+    void slotOpenKeyUrl();
 
     void slotNetworkUp();
     void slotNetworkDown();
@@ -224,6 +242,7 @@ private:
 
     QList<KGpgSignableNode *> signList;
     QList<KGpgKeyNode *> refreshList;
+    QHash<KJob *, KGpgNode *> m_addIds;	///< user ids to add to addressbook
 
     QClipboard::Mode m_clipboardmode;
 
@@ -257,6 +276,7 @@ private:
     KAction *openEditor;
     KAction *goToDefaultKey;
     KAction *exportPublicKey;
+    KAction *m_sendEmail;
     KAction *createGroup;
     KAction *m_groupRename;
     KAction *m_revokeKey;
